@@ -1,4 +1,5 @@
 """Expose submodules."""
+from .base_class import Place
 from .idiamant import NBG, NBR
 from .legrand import (
     NLC,
@@ -6,6 +7,7 @@ from .legrand import (
     NLF,
     NLFN,
     NLG,
+    NLIS,
     NLL,
     NLLM,
     NLLV,
@@ -15,10 +17,11 @@ from .legrand import (
     NLPC,
     NLPM,
     NLPS,
+    NLPT,
     NLT,
     NLV,
 )
-from .module import Camera, Module, Shutter, Switch
+from .module import Camera, Dimmer, Module, Shutter, Switch
 from .netatmo import (
     NCO,
     NDB,
@@ -44,47 +47,51 @@ from .netatmo import (
 from .smarther import BNS
 
 __all__ = [
-    "Shutter",
-    "Switch",
+    "BNS",
     "Camera",
+    "Dimmer",
+    "Location",
     "Module",
-    "NACamera",
-    "NOC",
     "NACamDoorTag",
-    "NIS",
-    "NCO",
-    "NSD",
-    "NLG",
-    "NLP",
-    "NLT",
-    "NLC",
-    "NLE",
-    "NLF",
-    "NLFN",
-    "NLL",
-    "NLLM",
-    "NLLV",
-    "NLM",
-    "NLPBS",
-    "NLPC",
-    "NLPM",
-    "NLPS",
-    "NLV",
-    "NBG",
-    "NBR",
-    "NDB",
-    "NRV",
-    "NAPlug",
-    "NATherm1",
-    "OTH",
-    "OTM",
+    "NACamera",
     "NAMain",
     "NAModule1",
     "NAModule2",
     "NAModule3",
     "NAModule4",
+    "NAPlug",
+    "NATherm1",
+    "NBG",
+    "NBR",
+    "NCO",
+    "NDB",
     "NHC",
-    "BNS",
+    "NIS",
+    "NLC",
+    "NLE",
+    "NLF",
+    "NLFN",
+    "NLG",
+    "NLIS",
+    "NLL",
+    "NLLM",
+    "NLLV",
+    "NLM",
+    "NLP",
+    "NLPBS",
+    "NLPC",
+    "NLPM",
+    "NLPS",
+    "NLPT",
+    "NLT",
+    "NLV",
+    "NOC",
+    "NRV",
+    "NSD",
+    "OTH",
+    "OTM",
+    "Place",
     "PublicWeatherArea",
-    "Location",
+    "Shutter",
+    "Switch",
 ]
